@@ -1,4 +1,4 @@
-/* $Id: directory-handle.cc,v 1.8 2003/07/18 04:53:54 mxpxpod Exp $ */               
+/* $Id: directory-handle.cc,v 1.10 2004/02/13 18:22:29 murrayc Exp $ */               
 
 /* Copyright 2003 gnome-vfsmm Development Team
  *
@@ -27,7 +27,7 @@ namespace
 
 //SignalProxy_Visit:
 
-//This Signal Proxy allows the C++ coder to specify a SigC::Slot instead of a static function.
+//This Signal Proxy allows the C++ coder to specify a sigc::slot instead of a static function.
 class SignalProxy_Visit
 {
 public:
@@ -94,7 +94,8 @@ DirectoryHandle::DirectoryHandle()
 
 DirectoryHandle::~DirectoryHandle()
 {
-  //TODO: close() it if it's open? murrayc.
+  if(gobj())
+    close();
 }
 
 void DirectoryHandle::open(const Glib::ustring& text_uri, FileInfoOptions options) throw(exception)
@@ -109,12 +110,13 @@ void DirectoryHandle::open(const Glib::RefPtr<const Uri>& uri, FileInfoOptions o
   handle_result(result);
 }
 
-
-
 void DirectoryHandle::close() throw(exception)
 {
-  GnomeVFSResult result = gnome_vfs_directory_close(gobj());
-  handle_result(result);
+  if(gobj_)
+  {
+    GnomeVFSResult result = gnome_vfs_directory_close(gobj());
+    handle_result(result);
+  }
 }
   
 Glib::RefPtr<FileInfo> DirectoryHandle::read_next(bool& file_exists) throw(exception)
